/*********************************************************************
 *
 *                Microchip USB C18 Firmware - Mouse Demo
 *
 *********************************************************************
 * FileName:        user_mouse.c
 * Dependencies:    See INCLUDES section below
 * Processor:       PIC18
 * Compiler:        C18 2.30.01+
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the CompanyE for its PICmicro Microcontroller is intended and
 * supplied to you, the Companys customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in violation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN AS ISECONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Rawin Rojvanit       11/19/04    Original.
 ********************************************************************/

/** I N C L U D E S **********************************************************/
#include <p18cxxx.h>
#include "system\typedefs.h"

#include "system\usb\usb.h"

#include "io_cfg.h"             // I/O pin mapping
#include "user.h"
#include "delays.h"

#include <timers.h>
#include <portb.h>

/** D E F I N E S ************************************************************/

#define	stepX1	PORTDbits.RD0
#define	dirX1	PORTDbits.RD1

#define	stepX2	PORTDbits.RD3
#define	dirX2	PORTDbits.RD2

#define	stepY1	PORTDbits.RD5
#define	dirY1	PORTDbits.RD4

#define	stepY2	PORTDbits.RD7
#define	dirY2	PORTDbits.RD6

#define	ch_etat PORTAbits.RA0
#define	ch_val	PORTAbits.RA1
#define	ch_auto PORTAbits.RA2
#define	OE		PORTAbits.RA3

/** V A R I A B L E S ********************************************************/
#pragma udata
unsigned char Buffer[64];

extern	timervaleur;

extern	X1;		// Nombres de pas 16bits signs
extern	X2;
extern	Y1;
extern	Y2;

extern	vX1;		// Vitesses 16bits non-signs
extern	vX2;
extern	vY1;
extern	vY2;

extern	c_vX1;		// Copie vitesses 16bits non-signs
extern	c_vX2;
extern	c_vY1;
extern	c_vY2;


extern chauffe;
extern c_chauffe;
extern rapport_chauffe;

extern flag0;			// Drapeau de test fonction D
//extern flag1;
//extern flag2;

/** P R I V A T E  P R O T O T Y P E S ***************************************/


/** D E C L A R A T I O N S **************************************************/
#pragma code
void UserInit(void)
{
	TRISD = 0;			// Sens et pas 4axes
	TRISC = 252;		// Par dfaut (gestion USB)
	TRISA = 243;		// 0 et 1 en sortie
	TRISB = 0xFF;		// Inutilis sauf pour interruption
	PORTC = 0;

	PORTD = 0;			// Etat par dfaut  l'init
	PORTA = 0;

/*	TRISBbits.TRISB4 = 0;
	TRISBbits.TRISB3 = 0;
	TRISBbits.TRISB2 = 0;
	TRISBbits.TRISB1 = 0;*/

	TRISBbits.TRISB7 = 0;

	OE = 0;
	
	stepX1 = 0;
	dirX1 = 1;
	stepX2 = 0;
	dirX2 = 1;

	stepY1 = 0;
	dirY1 = 1;
	stepY2 = 0;
	dirY2 = 1;
	
	ch_auto = 1;
	
    /* on cree le timer1 */
    OpenTimer1(TIMER_INT_ON & T1_16BIT_RW & T1_SOURCE_INT & T1_PS_1_1 & T1_OSC1EN_OFF & T1_SYNC_EXT_OFF);
//   	timervaleur=65000;  // valeur par dfaut
	 WriteTimer1(timervaleur);



    /* On active toutes les interruptions */
	PIE1bits.TMR1IE = 1;
    INTCONbits.PEIE = 1;
 	INTCONbits.GIE = 1;

}//end UserInit

/******************************************************************************
 * Function:        void ProcessIO(void)
 *
 * PreCondition:    None
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        This function is a place holder for other user routines.
 *                  It is a mixture of both USB and non-USB tasks.
 *
 * Note:            None
 *****************************************************************************/
void ProcessIO(void)
{   
	int i;
	int j;

//	if (HIDRxReport(Buffer,PacketSize ) > 0){}
//  if(!mHIDTxIsBusy()) HIDTxReport(Buffer, PacketSize);

	if (flag0 == 1)
	{
		if(c_vX1 == 0) c_vX1 = vX1;		// Initialisation des vitesses
		if(c_vX2 == 0) c_vX2 = vX2;
		if(c_vY1 == 0) c_vY1 = vY1;
		if(c_vY2 == 0) c_vY2 = vY2;
		if ((X1 == 0) & (X2 == 0) & (Y1 == 0) & (Y2 == 0))
		{
			Buffer[0] = 'S';
			if(!mHIDTxIsBusy()) HIDTxReport(Buffer, PacketSize);
			flag0 = 0;
		}
	}
	
	if (HIDRxReport(Buffer,PacketSize ) > 0)
	{
		if (Buffer[0] == 'F')			// Commande de fin d'usinage ou de stop
		{
 			OE = 0;
 			flag0 = 0;
 			
 			X1 = 0;
			vX1 = 0;	
			c_vX1 = 0;
			
			X2 = 0;
			vX2 = 0;	
			c_vX2 = 0;
			
			Y1 = 0;
			vY1 = 0;	
			c_vX1 = 0;
			
			Y2 = 0;
			vY2 = 0;	
			c_vY2 = 0;
			
			chauffe = 0;
			c_chauffe = 0;
		}
		
		if (Buffer[0] == 'D')			// Initilaisation pour l'usinage
		{
 			OE = 1;
 //			ch_auto = 1;
			Buffer[0] = 'S';			// Demande la synchro des donnes
			if(!mHIDTxIsBusy()) HIDTxReport(Buffer, PacketSize);
		}
		
		if (Buffer[0] == 'P')			// Fonction pause
		{
			PIE1bits.TMR1IE ^= 1;
										// Mise  0 de ch_auto
		}

		if(Buffer[0] == 'I')
		{		
			Buffer[0] = 'C';
			Buffer[1] = 1;
			Buffer[2] = 69;
			if(!mHIDTxIsBusy()) HIDTxReport(Buffer, PacketSize);
		}
		
		if(Buffer[0] == 'C')
		{
			chauffe = Buffer[1];
		}
		
		if (Buffer[0] == 'M')			// Commande moteur
		{
			i = 0;
			while (Buffer[i] != 0)
			{
				switch(Buffer[i+1])
				{
					case(0):
					case(1):					// Test lequel doit etre trait
						X1 = 0;
						vX1 = 0;
						dirX1 = 0;
						X1 = Buffer[i+2];		// Mise en forme des donnes recues
						X1 = X1<<8;
						X1 = Buffer[i+3] + X1;
						if(X1 < 0)
						{
							dirX1 = 1;
							X1 = ~X1;
							X1 = X1 + 1;
						}
						vX1 = Buffer[i+4];
						vX1 = vX1<<8;
						vX1 = Buffer[i+5] + vX1;
						flag0 = 1;
						break;
						
					case(2):					// Test lequel doit etre trait
						X2 = 0;
						vX2 = 0;
						dirX2 = 0;
						X2 = Buffer[i+2];		// Mise en forme des donnes recues
						X2 = X2<<8;
						X2 = Buffer[i+3] + X2;
						if(X2 < 0)
						{
							dirX2 = 1;
							X2 = ~X2;
							X2 = X2 + 1;
						}
						vX2 = Buffer[i+4];
						vX2 = vX2<<8;
						vX2 = Buffer[i+5] + vX2;
						flag0 = 1;
						break;
						
					case(3):					// Test lequel doit etre trait
						Y1 = 0;
						vY1 = 0;
						dirY1 = 0;
						Y1 = Buffer[i+2];		// Mise en forme des donnes recues
						Y1 = Y1<<8;
						Y1 = Buffer[i+3] + Y1;
						if(Y1 < 0)
						{
							dirY1 = 1;
							Y1 = ~Y1;
							Y1 = Y1 + 1;
						}
						vY1 = Buffer[i+4];
						vY1 = vY1<<8;
						vY1 = Buffer[i+5] + vY1;
						flag0 = 1;
						break;
						
					case(4):					// Test lequel doit etre trait
						Y2 = 0;
						vY2 = 0;
						dirY2 = 0;
						Y2 = Buffer[i+2];		// Mise en forme des donnes recues
						Y2 = Y2<<8;
						Y2 = Buffer[i+3] + Y2;
						if(Y2 < 0)
						{
							dirY2 = 1;
							Y2 = ~Y2;
							Y2 = Y2 + 1;
						}
						vY2 = Buffer[i+4];
						vY2 = vY2<<8;
						vY2 = Buffer[i+5] + vY2;
						flag0 = 1;
						break;
	
					default:
						Buffer[0] = 'E';					// Erreur si problme
						if(!mHIDTxIsBusy()) HIDTxReport(Buffer, PacketSize);
						flag0 = 0;
						break;
				}
			i = i + 6;
			}
			flag0 = 1;
			c_vX1 = vX1;		// Initialisation des vitesses
			c_vX2 = vX2;
			c_vY1 = vY1;
			c_vY2 = vY2;
		}
	}

}//end ProcessIO



/** EOF user_mouse.c *********************************************************/
